==> odfdo-3.16.8.tar.gz: odfdo-3.16.8/src/odfdo/utils/css3_colormap.py <==
# Copyright 2018-2025 Jérôme Dumonteil
# Copyright (c) 2009-2010 Ars Aperta, Itaapy, Pierlis, Talend.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
#
# Authors (odfdo project): jerome.dumonteil@gmail.com
# The odfdo project is a derivative work of the lpod-python project:
# https://github.com/lpod/lpod-python
"""Colormat of CSS3."""

CSS3_COLORMAP = {
    "indigo": (75, 0, 130),
    "gold": (255, 215, 0),
    "firebrick": (178, 34, 34),
    "indianred": (205, 92, 92),
    "yellow": (255, 255, 0),
    "darkolivegreen": (85, 107, 47),
    "darkseagreen": (143, 188, 143),
    "slategrey": (112, 128, 144),
    "darkslategrey": (47, 79, 79),
    "mediumvioletred": (199, 21, 133),
    "mediumorchid": (186, 85, 211),
    "chartreuse": (127, 255, 0),
    "mediumslateblue": (123, 104, 238),
    "black": (0, 0, 0),
    "springgreen": (0, 255, 127),
    "crimson": (220, 20, 60),
    "lightsalmon": (255, 160, 122),
    "brown": (165, 42, 42),
    "turquoise": (64, 224, 208),
    "olivedrab": (107, 142, 35),
    "lightcyan": (224, 255, 255),
    "cyan": (0, 255, 255),
    "silver": (192, 192, 192),
    "skyblue": (135, 206, 235),
    "gray": (128, 128, 128),
    "darkturquoise": (0, 206, 209),
    "goldenrod": (218, 165, 32),
    "darkgreen": (0, 100, 0),
    "darkviolet": (148, 0, 211),
    "darkgray": (169, 169, 169),
    "lightpink": (255, 182, 193),
    "teal": (0, 128, 128),
    "darkmagenta": (139, 0, 139),
    "lightgoldenrodyellow": (250, 250, 210),
    "lavender": (230, 230, 250),
    "yellowgreen": (154, 205, 50),
    "thistle": (216, 191, 216),
    "violet": (238, 130, 238),
    "navy": (0, 0, 128),
    "dimgrey": (105, 105, 105),
    "orchid": (218, 112, 214),
    "blue": (0, 0, 255),
    "ghostwhite": (248, 248, 255),
    "honeydew": (240, 255, 240),
    "cornflowerblue": (100, 149, 237),
    "darkblue": (0, 0, 139),
    "darkkhaki": (189, 183, 107),
    "mediumpurple": (147, 112, 216),
    "cornsilk": (255, 248, 220),
    "red": (255, 0, 0),
    "bisque": (255, 228, 196),
    "slategray": (112, 128, 144),
    "darkcyan": (0, 139, 139),
    "khaki": (240, 230, 140),
    "wheat": (245, 222, 179),
    "deepskyblue": (0, 191, 255),
    "darkred": (139, 0, 0),
    "steelblue": (70, 130, 180),
    "aliceblue": (240, 248, 255),
    "lightslategrey": (119, 136, 153),
    "gainsboro": (220, 220, 220),
    "mediumturquoise": (72, 209, 204),
    "floralwhite": (255, 250, 240),
    "plum": (221, 160, 221),
    "purple": (128, 0, 128),
    "lightgrey": (211, 211, 211),
    "burlywood": (222, 184, 135),
    "darksalmon": (233, 150, 122),
    "beige": (245, 245, 220),
    "azure": (240, 255, 255),
    "lightsteelblue": (176, 196, 222),
    "oldlace": (253, 245, 230),
    "greenyellow": (173, 255, 47),
    "royalblue": (65, 105, 225),
    "lightseagreen": (32, 178, 170),
    "sienna": (160, 82, 45),
    "lightcoral": (240, 128, 128),
    "orangered": (255, 69, 0),
    "navajowhite": (255, 222, 173),
    "lime": (0, 255, 0),
    "palegreen": (152, 251, 152),
    "mistyrose": (255, 228, 225),
    "seashell": (255, 245, 238),
    "mediumspringgreen": (0, 250, 154),
    "fuchsia": (255, 0, 255),
    "papayawhip": (255, 239, 213),
    "blanchedalmond": (255, 235, 205),
    "peru": (205, 133, 63),
    "aquamarine": (127, 255, 212),
    "white": (255, 255, 255),
    "darkslategray": (47, 79, 79),
    "lightgray": (211, 211, 211),
    "ivory": (255, 255, 240),
    "dodgerblue": (30, 144, 255),
    "lawngreen": (124, 252, 0),
    "chocolate": (210, 105, 30),
    "orange": (255, 165, 0),
    "forestgreen": (34, 139, 34),
    "darkgrey": (169, 169, 169),
    "olive": (128, 128, 0),
    "mintcream": (245, 255, 250),
    "antiquewhite": (250, 235, 215),
    "darkorange": (255, 140, 0),
    "cadetblue": (95, 158, 160),
    "moccasin": (255, 228, 181),
    "limegreen": (50, 205, 50),
    "saddlebrown": (139, 69, 19),
    "grey": (128, 128, 128),
    "darkslateblue": (72, 61, 139),
    "lightskyblue": (135, 206, 250),
    "deeppink": (255, 20, 147),
    "coral": (255, 127, 80),
    "aqua": (0, 255, 255),
    "darkgoldenrod": (184, 134, 11),
    "maroon": (128, 0, 0),
    "sandybrown": (244, 164, 96),
    "tan": (210, 180, 140),
    "magenta": (255, 0, 255),
    "rosybrown": (188, 143, 143),
    "pink": (255, 192, 203),
    "lightblue": (173, 216, 230),
    "palevioletred": (216, 112, 147),
    "mediumseagreen": (60, 179, 113),
    "slateblue": (106, 90, 205),
    "dimgray": (105, 105, 105),
    "powderblue": (176, 224, 230),
    "seagreen": (46, 139, 87),
    "snow": (255, 250, 250),
    "mediumblue": (0, 0, 205),
    "midnightblue": (25, 25, 112),
    "paleturquoise": (175, 238, 238),
    "palegoldenrod": (238, 232, 170),
    "whitesmoke": (245, 245, 245),
    "darkorchid": (153, 50, 204),
    "salmon": (250, 128, 114),
    "lightslategray": (119, 136, 153),
    "lemonchiffon": (255, 250, 205),
    "lightgreen": (144, 238, 144),
    "tomato": (255, 99, 71),
    "hotpink": (255, 105, 180),
    "lightyellow": (255, 255, 224),
    "lavenderblush": (255, 240, 245),
    "linen": (250, 240, 230),
    "mediumaquamarine": (102, 205, 170),
    "green": (0, 128, 0),
    "blueviolet": (138, 43, 226),
    "peachpuff": (255, 218, 185),
}

==> odfdo-3.18.0.tar.gz: odfdo-3.18.0/src/odfdo/utils/css3_colormap.py <==
# Copyright 2018-2025 Jérôme Dumonteil
# Copyright (c) 2009-2010 Ars Aperta, Itaapy, Pierlis, Talend.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
#
# Authors (odfdo project): jerome.dumonteil@gmail.com
# The odfdo project is a derivative work of the lpod-python project:
# https://github.com/lpod/lpod-python
"""A mapping of CSS3 color names to their corresponding RGB values.

This dictionary provides a convenient lookup for converting standard CSS color
names (e.g., 'red', 'blue', 'green') into their (R, G, B) integer tuples.
"""

CSS3_COLORMAP = {
    "indigo": (75, 0, 130),
    "gold": (255, 215, 0),
    "firebrick": (178, 34, 34),
    "indianred": (205, 92, 92),
    "yellow": (255, 255, 0),
    "darkolivegreen": (85, 107, 47),
    "darkseagreen": (143, 188, 143),
    "slategrey": (112, 128, 144),
    "darkslategrey": (47, 79, 79),
    "mediumvioletred": (199, 21, 133),
    "mediumorchid": (186, 85, 211),
    "chartreuse": (127, 255, 0),
    "mediumslateblue": (123, 104, 238),
    "black": (0, 0, 0),
    "springgreen": (0, 255, 127),
    "crimson": (220, 20, 60),
    "lightsalmon": (255, 160, 122),
    "brown": (165, 42, 42),
    "turquoise": (64, 224, 208),
    "olivedrab": (107, 142, 35),
    "lightcyan": (224, 255, 255),
    "cyan": (0, 255, 255),
    "silver": (192, 192, 192),
    "skyblue": (135, 206, 235),
    "gray": (128, 128, 128),
    "darkturquoise": (0, 206, 209),
    "goldenrod": (218, 165, 32),
    "darkgreen": (0, 100, 0),
    "darkviolet": (148, 0, 211),
    "darkgray": (169, 169, 169),
    "lightpink": (255, 182, 193),
    "teal": (0, 128, 128),
    "darkmagenta": (139, 0, 139),
    "lightgoldenrodyellow": (250, 250, 210),
    "lavender": (230, 230, 250),
    "yellowgreen": (154, 205, 50),
    "thistle": (216, 191, 216),
    "violet": (238, 130, 238),
    "navy": (0, 0, 128),
    "dimgrey": (105, 105, 105),
    "orchid": (218, 112, 214),
    "blue": (0, 0, 255),
    "ghostwhite": (248, 248, 255),
    "honeydew": (240, 255, 240),
    "cornflowerblue": (100, 149, 237),
    "darkblue": (0, 0, 139),
    "darkkhaki": (189, 183, 107),
    "mediumpurple": (147, 112, 216),
    "cornsilk": (255, 248, 220),
    "red": (255, 0, 0),
    "bisque": (255, 228, 196),
    "slategray": (112, 128, 144),
    "darkcyan": (0, 139, 139),
    "khaki": (240, 230, 140),
    "wheat": (245, 222, 179),
    "deepskyblue": (0, 191, 255),
    "darkred": (139, 0, 0),
    "steelblue": (70, 130, 180),
    "aliceblue": (240, 248, 255),
    "lightslategrey": (119, 136, 153),
    "gainsboro": (220, 220, 220),
    "mediumturquoise": (72, 209, 204),
    "floralwhite": (255, 250, 240),
    "plum": (221, 160, 221),
    "purple": (128, 0, 128),
    "lightgrey": (211, 211, 211),
    "burlywood": (222, 184, 135),
    "darksalmon": (233, 150, 122),
    "beige": (245, 245, 220),
    "azure": (240, 255, 255),
    "lightsteelblue": (176, 196, 222),
    "oldlace": (253, 245, 230),
    "greenyellow": (173, 255, 47),
    "royalblue": (65, 105, 225),
    "lightseagreen": (32, 178, 170),
    "sienna": (160, 82, 45),
    "lightcoral": (240, 128, 128),
    "orangered": (255, 69, 0),
    "navajowhite": (255, 222, 173),
    "lime": (0, 255, 0),
    "palegreen": (152, 251, 152),
    "mistyrose": (255, 228, 225),
    "seashell": (255, 245, 238),
    "mediumspringgreen": (0, 250, 154),
    "fuchsia": (255, 0, 255),
    "papayawhip": (255, 239, 213),
    "blanchedalmond": (255, 235, 205),
    "peru": (205, 133, 63),
    "aquamarine": (127, 255, 212),
    "white": (255, 255, 255),
    "darkslategray": (47, 79, 79),
    "lightgray": (211, 211, 211),
    "ivory": (255, 255, 240),
    "dodgerblue": (30, 144, 255),
    "lawngreen": (124, 252, 0),
    "chocolate": (210, 105, 30),
    "orange": (255, 165, 0),
    "forestgreen": (34, 139, 34),
    "darkgrey": (169, 169, 169),
    "olive": (128, 128, 0),
    "mintcream": (245, 255, 250),
    "antiquewhite": (250, 235, 215),
    "darkorange": (255, 140, 0),
    "cadetblue": (95, 158, 160),
    "moccasin": (255, 228, 181),
    "limegreen": (50, 205, 50),
    "saddlebrown": (139, 69, 19),
    "grey": (128, 128, 128),
    "darkslateblue": (72, 61, 139),
    "lightskyblue": (135, 206, 250),
    "deeppink": (255, 20, 147),
    "coral": (255, 127, 80),
    "aqua": (0, 255, 255),
    "darkgoldenrod": (184, 134, 11),
    "maroon": (128, 0, 0),
    "sandybrown": (244, 164, 96),
    "tan": (210, 180, 140),
    "magenta": (255, 0, 255),
    "rosybrown": (188, 143, 143),
    "pink": (255, 192, 203),
    "lightblue": (173, 216, 230),
    "palevioletred": (216, 112, 147),
    "mediumseagreen": (60, 179, 113),
    "slateblue": (106, 90, 205),
    "dimgray": (105, 105, 105),
    "powderblue": (176, 224, 230),
    "seagreen": (46, 139, 87),
    "snow": (255, 250, 250),
    "mediumblue": (0, 0, 205),
    "midnightblue": (25, 25, 112),
    "paleturquoise": (175, 238, 238),
    "palegoldenrod": (238, 232, 170),
    "whitesmoke": (245, 245, 245),
    "darkorchid": (153, 50, 204),
    "salmon": (250, 128, 114),
    "lightslategray": (119, 136, 153),
    "lemonchiffon": (255, 250, 205),
    "lightgreen": (144, 238, 144),
    "tomato": (255, 99, 71),
    "hotpink": (255, 105, 180),
    "lightyellow": (255, 255, 224),
    "lavenderblush": (255, 240, 245),
    "linen": (250, 240, 230),
    "mediumaquamarine": (102, 205, 170),
    "green": (0, 128, 0),
    "blueviolet": (138, 43, 226),
    "peachpuff": (255, 218, 185),
}
